
COLUMNS_MENU2205_BASIS = ['일자', '자산', '종목명', '종목']

# COLUMNS_MENU2205_PRIMARY = 

COLUMNS_MENU2205_CATEGORY_HOLDINGS_USD = ['외화 보유정보: 외화취득액', '외화 보유정보: 외화평가액', '외화 보유정보: 손익률', '외화 보유정보: 취득단가']

COLUMNS_MENU2205_CATEGORY_WEIGHT = ['비중: 주식/채권', '비중: 자산대비', '비중: 시장대비', '비중: 시장비중']

COLUMNS_MENU2205_CATEGORY_LENDING = ['대여정보: 대용/담보수량', '대여정보: 대여수량', '대여정보: 대용비율', '대여정보: 대여비율']

COLUMNS_MENU2205_CATEGORY_EVALUATION = ['평가정보: 종가',
 '평가정보: 증감',
 '평가정보: 시가수익률',
 '평가정보: 증감',
 '평가정보: 3사평균',
 '평가정보: 4사평균',
 '평가정보: KBP가격',
 '평가정보: NICE가격',
 '평가정보: KIS가격',
 '평가정보: FNP가격',
 '평가정보: 3사평균YTM',
 '평가정보: 4사평균YTM',
 '평가정보: KBP YTM',
 '평가정보: NICE YTM',
 '평가정보: KIS YTM',
 '평가정보: FNP YTM']

COLUMNS_MENU2205_CATEGORY_INFO_STOCK = ['종목정보: 표면금리',
 '종목정보: 할인율',
 '종목정보: 매입수익률',
 '종목정보: 회계적수익률',
 '종목정보: 발행일',
 '종목정보: 만기일',
 '종목정보: 편입일',
 '종목정보: 업종구분/보증기관',
 '종목정보: 발행국가',
 '종목정보: 보증기관',
 '종목정보: 베타',
 '종목정보: 지수가중베타',
 '종목정보: 듀레이션',
 '종목정보: 컨벡시티',
 '종목정보: KBP듀레이션',
 '종목정보: KBP컨벡시티',
 '종목정보: KIS듀레이션',
 '종목정보: KIS컨벡시티',
 '종목정보: NICE듀레이션',
 '종목정보: NICE컨벡시티',
 '종목정보: FNP듀레이션',
 '종목정보: FNP컨벡시티',
 '종목정보: 신용등급',
 '종목정보: 잔존일수',
 '종목정보: 표시통화',
 '종목정보: 옵션행사일',
 '종목정보: 발행기관',
 '종목정보: 이자지급방법',
 '종목정보: 자산분류',
 '종목정보: 시가총액']

COLUMNS_MENU2205_CATEGORY_INFO_ASSET = ['자산정보: 순자산',
 '자산정보: 총자산',
 '자산정보: 기준가격',
 '자산정보: 증감',
 '자산정보: ISIN코드',
 '자산정보: TICKER']

ASSET_CATEGORIES = ['국내주식', '국내채권', 'REPO 매수', 'REPO', '국내현금', '국내선물', '국내수익증권',
       '국내수익증권(ETF)', '외화주식', '외화현금성', '외화스왑', '기타', '기타(총계정원장)', '총계정원장',
       '차입금']


# df.loc[df['name']=='그래피2우선주(전환상환)', 'hotfix'] = '그래피'
# df.loc[df['name']=='차바이오텍3우선주', 'hotfix'] = '차바이오텍'
# df.loc[df['name']=='두나무(주)', 'hotfix'] = '두나무'
