
MAPPING_NAMES_TO_CORPNAMES_FOR_EXCEPTIONS = {
    '그래피2우선주(전환상환)': '그래피',
    '차바이오텍3우선주': '차바이오텍',
    '두나무(주)': '두나무',
    '윈텍글로비스보통주': '윈텍글로비스',
    '에버베스트헬리오스파워PEF(241211)': '일렉트로엠',
    '메를로랩 보통주': '메를로랩',
    '규원테크 1우선주 240708 (002)': '규원테크',
    '글라세움 4우선주 221014 (002)': '글라세움',
    '이피캠텍 주식회사 보통주': '이피캠텍',
    '비브로스 보통주': '비브로스',
}