from .office_system_dataset_cleanser import preprocess_columns_in_multi_columned_df, preprocess_multi_columned_df, classify_category_in_multi_columned_df
from .office_system_dataset_utils import parse_commaed_number, force_int

preprocess_cols_menu2205 = preprocess_columns_in_multi_columned_df
classify_columns_menu2205 = classify_category_in_multi_columned_df

format_commaed_number = parse_commaed_number
format_integer = force_int